@@ -10,7 +10,7 @@
 #' of using the default one-sided alternative ("greater"), we use the
 #' two-sided alternative.
 #'
-#' To interpret the sr2, use [effectsize::interpret_omega_squared()].
+#' To interpret the sr2, use [effectsize::interpret_r2_semipartial()].
 #'
 #' For the *easystats* equivalent, use [report::report()] on the [lm()]
 #' model object.
@@ -71,8 +71,9 @@ nice_lm <- function(model,
                     ci.alternative = "two.sided",
                     ...) {
   rlang::check_installed("effectsize",
-                         version = get_dep_version("effectsize"),
-                         reason = "for this function.")
+    version = get_dep_version("effectsize"),
+    reason = "for this function."
+  )
   if (inherits(model, "list") && all(unlist(lapply(model, inherits, "lm")))) {
     models.list <- model
   } else if (inherits(model, "lm")) {
